"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.useFakeHighlight = useFakeHighlight;
var _vue = require("vue");
var _state = require("@tiptap/pm/state");
var _view = require("@tiptap/pm/view");
function hasValidSelection(editor) {
  return !editor.state.selection.empty && editor.state.selection.from && editor.state.selection.to;
}
function useFakeHighlight(editorRef, options = {}) {
  const {
    highlightClass = "bg-blue/50"
  } = options;
  const position = (0, _vue.ref)(null);
  const key = new _state.PluginKey("fake-highlight");
  const META_KEY = "fake-highlight";
  const shouldHighlight = (0, _vue.ref)(true);
  function updateDecoration() {
    const editor = (0, _vue.toValue)(editorRef);
    if (!editor || !shouldHighlight.value) {
      return;
    }
    const transaction = editor.state.tr.setMeta(META_KEY, "run");
    editor.view.dispatch(transaction);
  }
  function highlight(range) {
    const editor = (0, _vue.toValue)(editorRef);
    if (!editor) {
      return;
    }
    if (range || hasValidSelection(editor)) {
      position.value = range ?? {
        from: editor.state.selection.from,
        to: editor.state.selection.to
      };
      updateDecoration();
    }
  }
  function unhighlight() {
    position.value = null;
    updateDecoration();
  }
  (0, _vue.onMounted)(() => {
    const editor = (0, _vue.toValue)(editorRef);
    if (!editor) {
      return;
    }
    editor.registerPlugin(new _state.Plugin({
      key,
      state: {
        init(_config, state) {
          return _view.DecorationSet.create(state.doc, []);
        },
        apply(tr, oldState) {
          if (!tr.getMeta(META_KEY)) {
            return oldState;
          }
          if (position.value && shouldHighlight.value) {
            const decoration = _view.Decoration.inline(position.value.from, position.value.to, {
              class: highlightClass
            });
            return _view.DecorationSet.create(tr.doc, [decoration]);
          }
          return _view.DecorationSet.create(tr.doc, []);
        }
      },
      props: {
        decorations(state) {
          return this.getState(state);
        }
      }
    }));
  });
  (0, _vue.onBeforeUnmount)(() => {
    const editor = (0, _vue.toValue)(editorRef);
    if (editor) {
      editor.unregisterPlugin(key);
    }
  });
  return {
    highlight,
    unhighlight
  };
}