"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.useLinkHover = useLinkHover;
var _vue = require("vue");
var _state = require("@tiptap/pm/state");
var _core = require("@vueuse/core");
function useLinkHover(editorRef, options = {}) {
  const editor = (0, _vue.toValue)(editorRef);
  const {
    immediatelyClose = false,
    delay = 400
  } = options;
  const to = (0, _vue.ref)(null);
  const isHovered = (0, _vue.ref)(false);
  const reference = (0, _vue.ref)(null);
  const hoveredLink = (0, _vue.ref)(null);
  const pluginKey = new _state.PluginKey("link-hover");
  const {
    start,
    stop
  } = (0, _core.useTimeoutFn)(el => {
    if (!el) {
      isHovered.value = false;
      return;
    }
    hoveredLink.value = el;
    isHovered.value = true;
    reference.value = {
      from: el.pmViewDesc?.posAtStart ?? 0,
      to: el.pmViewDesc?.posAtEnd ?? 0
    };
    to.value = el.href;
  }, delay, {
    immediate: false
  });
  (0, _vue.onMounted)(() => {
    if (!editor) {
      return;
    }
    editor.registerPlugin(new _state.Plugin({
      key: pluginKey,
      props: {
        handleDOMEvents: {
          mouseover(view, event) {
            let el = event.target;
            while (el.tagName !== "A" && el.parentElement) {
              el = el.parentElement;
            }
            if (el.tagName !== "A") {
              return;
            }
            start(el);
            return true;
          },
          mouseout(view, event) {
            const el = event.target;
            stop();
            if (reference.value?.from === el.pmViewDesc?.posAtStart && reference.value?.to === el.pmViewDesc?.posAtEnd && immediatelyClose) {
              isHovered.value = false;
              reference.value = null;
              hoveredLink.value = null;
              return true;
            }
            return false;
          }
        }
      },
      // Recalculate reference on content update
      state: {
        init() {
          return {};
        },
        apply(tr, value) {
          if (tr.docChanged && hoveredLink.value) {
            reference.value = {
              from: hoveredLink.value.pmViewDesc?.posAtStart ?? 0,
              to: hoveredLink.value.pmViewDesc?.posAtEnd ?? 0
            };
          }
          return value;
        }
      }
    }));
  });
  (0, _vue.onBeforeUnmount)(() => {
    if (!editor) {
      return;
    }
    editor.unregisterPlugin(pluginKey);
  });
  return {
    isHovered,
    reference,
    to: (0, _vue.readonly)(to)
  };
}