import { ref, onMounted, onBeforeUnmount, readonly, toValue } from "vue";
import { Plugin, PluginKey } from "@tiptap/pm/state";
import { useTimeoutFn } from "@vueuse/core";
export function useLinkHover(editorRef, options = {}) {
  const editor = toValue(editorRef);
  const { immediatelyClose = false, delay = 400 } = options;
  const to = ref(null);
  const isHovered = ref(false);
  const reference = ref(null);
  const hoveredLink = ref(null);
  const pluginKey = new PluginKey("link-hover");
  const { start, stop } = useTimeoutFn(
    (el) => {
      if (!el) {
        isHovered.value = false;
        return;
      }
      hoveredLink.value = el;
      isHovered.value = true;
      reference.value = {
        from: el.pmViewDesc?.posAtStart ?? 0,
        to: el.pmViewDesc?.posAtEnd ?? 0
      };
      to.value = el.href;
    },
    delay,
    {
      immediate: false
    }
  );
  onMounted(() => {
    if (!editor) {
      return;
    }
    editor.registerPlugin(
      new Plugin({
        key: pluginKey,
        props: {
          handleDOMEvents: {
            mouseover(view, event) {
              let el = event.target;
              while (el.tagName !== "A" && el.parentElement) {
                el = el.parentElement;
              }
              if (el.tagName !== "A") {
                return;
              }
              start(el);
              return true;
            },
            mouseout(view, event) {
              const el = event.target;
              stop();
              if (reference.value?.from === el.pmViewDesc?.posAtStart && reference.value?.to === el.pmViewDesc?.posAtEnd && immediatelyClose) {
                isHovered.value = false;
                reference.value = null;
                hoveredLink.value = null;
                return true;
              }
              return false;
            }
          }
        },
        // Recalculate reference on content update
        state: {
          init() {
            return {};
          },
          apply(tr, value) {
            if (tr.docChanged && hoveredLink.value) {
              reference.value = {
                from: hoveredLink.value.pmViewDesc?.posAtStart ?? 0,
                to: hoveredLink.value.pmViewDesc?.posAtEnd ?? 0
              };
            }
            return value;
          }
        }
      })
    );
  });
  onBeforeUnmount(() => {
    if (!editor) {
      return;
    }
    editor.unregisterPlugin(pluginKey);
  });
  return {
    isHovered,
    reference,
    to: readonly(to)
  };
}
