"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.CommandExtension = void 0;
var _core = require("@tiptap/core");
var _suggestion = _interopRequireDefault(require("@tiptap/suggestion"));
function _interopRequireDefault(e) { return e && e.__esModule ? e : { default: e }; }
const suggestion = {
  render: () => {
    let commandProps = null;
    return {
      onStart: props => {
        commandProps = props;
        if (!props.clientRect) {
          return;
        }
        const tr = props.editor.view.state.tr.setMeta("suggestionProps", {
          clientRect: props.clientRect,
          active: true,
          props: commandProps
        });
        props.editor.view.dispatch(tr);
      },
      onUpdate(props) {
        commandProps = props;
        if (!props.clientRect) {
          return;
        }
        const tr = props.editor.view.state.tr.setMeta("suggestionProps", {
          clientRect: props.clientRect,
          active: true,
          props: commandProps
        });
        props.editor.view.dispatch(tr);
      },
      onKeyDown(props) {
        if (props.event.key === "Escape") {
          const tr2 = props.view.state.tr.setMeta("suggestionProps", {
            active: false
          });
          props.view.dispatch(tr2);
          return true;
        }
        const tr = props.view.state.tr.setMeta("suggestionKeyDown", props);
        props.view.dispatch(tr);
        if (["ArrowUp", "ArrowDown", "Enter"].includes(props.event.key)) {
          return true;
        }
      },
      onExit() {
        if (commandProps?.editor) {
          const tr = commandProps.editor.view.state.tr.setMeta("suggestionProps", {
            active: false
          });
          commandProps.editor.view.dispatch(tr);
        }
      }
    };
  }
};
const CommandExtension = () => {
  const extension = _core.Extension.create({
    name: "custom-commands",
    addOptions() {
      return {
        suggestion: {
          char: "/",
          command: ({
            editor,
            range,
            props
          }) => {
            props.command({
              editor,
              range
            });
          }
        }
      };
    },
    addProseMirrorPlugins() {
      return [(0, _suggestion.default)({
        editor: this.editor,
        ...this.options.suggestion
      })];
    }
  });
  return extension.configure({
    suggestion
  });
};
exports.CommandExtension = CommandExtension;