import { Extension } from "@tiptap/core";
import Suggestion from "@tiptap/suggestion";
const suggestion = {
  render: () => {
    let commandProps = null;
    return {
      onStart: (props) => {
        commandProps = props;
        if (!props.clientRect) {
          return;
        }
        const tr = props.editor.view.state.tr.setMeta("suggestionProps", {
          clientRect: props.clientRect,
          active: true,
          props: commandProps
        });
        props.editor.view.dispatch(tr);
      },
      onUpdate(props) {
        commandProps = props;
        if (!props.clientRect) {
          return;
        }
        const tr = props.editor.view.state.tr.setMeta("suggestionProps", {
          clientRect: props.clientRect,
          active: true,
          props: commandProps
        });
        props.editor.view.dispatch(tr);
      },
      onKeyDown(props) {
        if (props.event.key === "Escape") {
          const tr2 = props.view.state.tr.setMeta("suggestionProps", {
            active: false
          });
          props.view.dispatch(tr2);
          return true;
        }
        const tr = props.view.state.tr.setMeta("suggestionKeyDown", props);
        props.view.dispatch(tr);
        if (["ArrowUp", "ArrowDown", "Enter"].includes(props.event.key)) {
          return true;
        }
      },
      onExit() {
        if (commandProps?.editor) {
          const tr = commandProps.editor.view.state.tr.setMeta(
            "suggestionProps",
            {
              active: false
            }
          );
          commandProps.editor.view.dispatch(tr);
        }
      }
    };
  }
};
export const CommandExtension = () => {
  const extension = Extension.create({
    name: "custom-commands",
    addOptions() {
      return {
        suggestion: {
          char: "/",
          command: ({ editor, range, props }) => {
            props.command({ editor, range });
          }
        }
      };
    },
    addProseMirrorPlugins() {
      return [
        Suggestion({
          editor: this.editor,
          ...this.options.suggestion
        })
      ];
    }
  });
  return extension.configure({
    suggestion
  });
};
