"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.LinkExtension = void 0;
var _extensionLink = require("@tiptap/extension-link");
var _state = require("@tiptap/pm/state");
var _defu = require("defu");
const LinkExtension = (options = {}) => {
  const defaultOptions = {
    openOnClick: false,
    openOnMetaClick: true,
    autolink: false
  };
  const mergedOptions = (0, _defu.defu)(options, defaultOptions);
  const {
    openOnMetaClick
  } = mergedOptions;
  return _extensionLink.Link.configure(mergedOptions).extend({
    addProseMirrorPlugins() {
      return [...(openOnMetaClick ? [new _state.Plugin({
        key: new _state.PluginKey("linkClickHandler"),
        props: {
          handleClick: (view, _pos, event) => {
            const qualifiedClick = event.button === 1 || event.button === 0 && (event.metaKey || event.ctrlKey);
            if (!view.editable || !qualifiedClick) {
              return false;
            }
            let target = event.target;
            while (target !== null && target.nodeName !== "A" && target.nodeName !== "DIV") {
              target = target.parentNode;
            }
            if (target?.nodeName !== "A") {
              return false;
            }
            const href = target.getAttribute("href");
            if (href === null) {
              return false;
            }
            window.open(href, "_blank", "noopener noreferrer");
            return true;
          }
        }
      })] : [])];
    }
  });
};
exports.LinkExtension = LinkExtension;